@@ -1,4 +1,21 @@
+# Copyright (C) <2021>  YUANXIN INFORMATION TECHNOLOGY GROUP CO.LTD and Jinzhe Wang
+# This file is part of uitestrunner_syberos
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
+
 from time import sleep
+from lxml import etree
 
 
 class Events:
@@ -92,8 +109,20 @@ class Events:
     def back(self):
         return self.__reply_status_check(self.device.con.get(path="sendBackKeyEvent"))
 
-    def home(self):
-        return self.__reply_status_check(self.device.con.get(path="sendHomeKeyEvent"))
+    def home(self, timeout=None):
+        if not timeout:
+            timeout = self.device.default_timeout
+        if self.__reply_status_check(self.device.con.get(path="sendHomeKeyEvent")):
+            for m_iter in range(0, timeout):
+                if m_iter > 0:
+                    sleep(1)
+                self.device.refresh_layout()
+                selector = etree.XML(self.device.xmlStr.encode('utf-8'))
+                if selector.get("sopId") == "":
+                    return True
+                else:
+                    self.device.con.get(path="sendHomeKeyEvent")
+        return False
 
     def menu(self):
         return self.__reply_status_check(self.device.con.get(path="sendMenuKeyEvent"))
@@ -104,3 +133,22 @@ class Events:
     def volume_down(self, delay=0):
         return self.__reply_status_check(self.device.con.get(path="sendVolumeDownKeyEvent", args="delay=" + str(delay)))
 
+    def set_rotation_allowed(self, allowed=True):
+        if allowed:
+            return self.__reply_status_check(self.device.con.get(path="setRotationAllowed", args="allowed=1"))
+        else:
+            return self.__reply_status_check(self.device.con.get(path="setRotationAllowed", args="allowed=0"))
+
+    def get_rotation_allowed(self):
+        reply = int(str(self.device.con.get(path="getRotationAllowed").read(), 'utf-8'))
+        if reply == 1:
+            return True
+        return False
+
+    def set_rotation(self, rotation: int):
+        return self.__reply_status_check(self.device.con.get(path="setCurrentOrientation", args="rotation=" + str(rotation)))
+
+    def get_rotation(self):
+        return int(str(self.device.con.get(path="getCurrentOrientation").read(), 'utf-8'))
+
+
